@@ -36,7 +36,10 @@ def _replace_default_placeholders(ret, defaults):
 def _reroot_paths(defaults, root):
     for imp in defaults:
         for key, val in defaults[imp].items():
-            path = pathlib.Path(val or "")
+            try:
+                path = pathlib.Path(val or "")
+            except TypeError:
+                continue
             if key == "root_dir":
                 defaults[imp][key] = root
             elif (key.endswith(("_dir", "_path", "_file"))) and path.is_absolute():
