@@ -9,6 +9,12 @@ def run(hub, primary):
     """
     Check the version number and then exit
     """
-    mod = importlib.import_module(f"{primary}.version")
-    print(f"{primary} {mod.version}")
+    v = hub.config.version.get(primary)
+
+    print(f"{primary} {v}")
     sys.exit(0)
+
+
+def get(hub, primary):
+    mod = importlib.import_module(f"{primary}.version")
+    return mod.version
